#!/usr/bin/env python
# -*- coding:UTF-8 -*-
"""
    This file will control some options of the gmoccapy plasma screen
    and demonstrats at the same time the possibilities you have introducing
    your own handler files and functions to that screen, showing the
    possibilities to modify the layout and behavior

    Copyright 2013 Norbert Schechner
    nieson@web.de

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

	Modified 12/16 to support my plasma tab  JDM
"""
import math
import hal_glib                           # needed to make our own hal pins
import hal                                # needed to make our own hal pins
from gladevcp.persistence import IniFile  # we use this one to save the states of the widgets on shut down and restart
from gladevcp.persistence import widget_defaults
from gladevcp.persistence import select_widgets
import gtk
from gmoccapy import preferences
from gmoccapy import getiniinfo


class THC_Gains_TabClass:

    def __init__(self, halcomp, builder, useropts):
        self.builder = builder
        self.halcomp = halcomp
        self.defaults = { IniFile.vars : { "Pgainval"       : 1.0 ,
                                           "Pgainmax"       : 100.0 ,
                                           "Pgainmin"       : 0.0  ,
                                           "Pgainincr"      : 0.01  ,

                                           "Dgainval"         : 0.0  ,
                                           "Dgainmax"         : 100.0 ,
                                           "Dgainmin"         : 0.0  ,
                                           "Dgainincr"        : 0.001,

                                           "Igainval"          : 0.0 ,
                                           "Igainmax"          : 100.0 ,
                                           "Igainmin"          : 0.0  ,
                                           "Igainincr"         : 0.001  

                                         
                                         },
                        }

        get_ini_info = getiniinfo.GetIniInfo()
        prefs = preferences.preferences(get_ini_info.get_preference_file_path())
        theme_name = prefs.getpref("gtk_theme", "Follow System Theme", str)
        if theme_name == "Follow System Theme":
            theme_name = gtk.settings_get_default().get_property("gtk-theme-name")
        gtk.settings_get_default().set_string_property("gtk-theme-name", theme_name, "")

        self.ini_filename = __name__ + ".var"
        self.ini = IniFile(self.ini_filename, self.defaults, self.builder)
        self.ini.restore_state(self)

        # lets make our pins
        self.THC_Gain_P = hal_glib.GPin(halcomp.newpin("THC-Pgain", hal.HAL_FLOAT, hal.HAL_OUT))
        self.THC_Gain_D = hal_glib.GPin(halcomp.newpin("THC-Dgain", hal.HAL_FLOAT, hal.HAL_OUT))
        self.THC_Gain_I = hal_glib.GPin(halcomp.newpin("THC-Igain", hal.HAL_FLOAT, hal.HAL_OUT))

        # get all widgets and connect them
        self.lbl_thc_pgain = self.builder.get_object("lbl_thc_pgain")
        self.lbl_thc_dgain = self.builder.get_object("lbl_thc_dgain")
        self.lbl_thc_igain = self.builder.get_object("lbl_thc_igain")

        self.btn_THC_pgain_minus = self.builder.get_object("btn_THC_pgain_minus")
        self.btn_THC_pgain_minus.connect("pressed", self.on_btn_THC_pgain_pressed, -1)

        self.btn_THC_pgain_plus = self.builder.get_object("btn_THC_pgain_plus")
        self.btn_THC_pgain_plus.connect("pressed", self.on_btn_THC_pgain_pressed, 1)

        self.adj_THC_pgain = self.builder.get_object("adj_THC_pgain")
        self.adj_THC_pgain.connect("value_changed", self.on_adj_THC_pgain_value_changed)
        self.adj_THC_pgain.upper = self.Pgainmax
        self.adj_THC_pgain.lower = self.Pgainmin
        self.adj_THC_pgain.set_value(self.Pgainval)

        self.btn_THC_dgain_minus = self.builder.get_object("btn_THC_dgain_minus")
        self.btn_THC_dgain_minus.connect("pressed", self.on_btn_THC_dgain_pressed, -1)

        self.btn_THC_dgain_plus = self.builder.get_object("btn_THC_dgain_plus")
        self.btn_THC_dgain_plus.connect("pressed", self.on_btn_THC_dgain_pressed, 1)

        self.adj_THC_dgain = self.builder.get_object("adj_THC_dgain")
        self.adj_THC_dgain.connect("value_changed", self.on_adj_THC_dgain_value_changed)
        self.adj_THC_dgain.upper = self.Dgainmax
        self.adj_THC_dgain.lower = self.Dgainmin
        self.adj_THC_dgain.set_value(self.Dgainval)

        self.btn_THC_igain_minus = self.builder.get_object("btn_THC_igain_minus")
        self.btn_THC_igain_minus.connect("pressed", self.on_btn_THC_igain_pressed, -1)

        self.btn_THC_igain_plus = self.builder.get_object("btn_THC_igain_plus")
        self.btn_THC_igain_plus.connect("pressed", self.on_btn_THC_igain_pressed, 1)

        self.adj_THC_igain = self.builder.get_object("adj_THC_igain")
        self.adj_THC_igain.connect("value_changed", self.on_adj_THC_igain_value_changed)
        self.adj_THC_igain.upper = self.Igainmax
        self.adj_THC_igain.lower = self.Igainmin
        self.adj_THC_igain.set_value(self.Igainval)

         #end of local hal pin connections

        #this must stay with the _on_destroy definition
        self.tbl_cutting = self.builder.get_object("tbl_cutting")
        self.tbl_cutting.connect("destroy", self._on_destroy)

    def _on_destroy(self, obj, data = None):
        self.ini.save_state(self)

    # What to do on button pres events?
    def on_btn_THC_pgain_pressed(self, widget, dir):
        increment = self.Pgainincr * dir
        self.Pgainval = self.adj_THC_pgain.get_value() + increment
        self.adj_THC_pgain.set_value(self.Pgainval)

    def on_btn_THC_dgain_pressed(self, widget, dir):
        increment = self.Dgainincr * dir
        self.Dgainval = self.adj_THC_dgain.get_value() + increment
        self.adj_THC_dgain.set_value(self.Dgainval)

    def on_btn_THC_igain_pressed(self, widget, dir):
        increment = self.Igainincr * dir
        self.Igainval = self.adj_THC_igain.get_value() + increment
        self.adj_THC_igain.set_value(self.Igainval)

    # and the behavior of the adjustments to control max and min values
    def on_adj_THC_pgain_value_changed(self, widget, data = None):
        if widget.get_value() >= widget.upper:
            self.btn_THC_pgain_plus.set_sensitive(False)
        elif widget.get_value() <= widget.lower:
            self.btn_THC_pgain_minus.set_sensitive(False)
        else:
            self.btn_THC_pgain_plus.set_sensitive(True)
            self.btn_THC_pgain_minus.set_sensitive(True)
        self.halcomp["THC-Pgain"] = widget.get_value()
        self.lbl_thc_pgain.set_label("%.2f" % (widget.get_value()))

    def on_adj_THC_dgain_value_changed(self, widget, data = None):
        if widget.get_value() >= widget.upper:
            self.btn_THC_dgain_plus.set_sensitive(False)
        elif widget.get_value() <= widget.lower:
            self.btn_THC_dgain_minus.set_sensitive(False)
        else:
            self.btn_THC_dgain_plus.set_sensitive(True)
            self.btn_THC_dgain_minus.set_sensitive(True)
        self.halcomp["THC-Dgain"] = widget.get_value() 
        self.lbl_thc_dgain.set_label("%.3f" % widget.get_value())

    def on_adj_THC_igain_value_changed(self, widget, data = None):
        if widget.get_value() >= widget.upper:
            self.btn_THC_igain_plus.set_sensitive(False)
        elif widget.get_value() <= widget.lower:
            self.btn_THC_igain_minus.set_sensitive(False)
        else:
            self.btn_THC_igain_plus.set_sensitive(True)
            self.btn_THC_igain_minus.set_sensitive(True)
        self.halcomp["THC-Igain"] = widget.get_value()
        self.lbl_thc_igain.set_label("%.3f" % widget.get_value())

def get_handlers(halcomp, builder, useropts):
    return[THC_Gains_TabClass(halcomp, builder, useropts)]
