#!/usr/bin/env python
# -*- coding:UTF-8 -*-
"""
    This file will control some options of the gmoccapy plasma screen
    and demonstrats at the same time the possibilities you have introducing
    your own handler files and functions to that screen, showing the
    possibilities to modify the layout and behavior

    Copyright 2013 Norbert Schechner
    nieson@web.de
    modified 12/16 to work with my table JDM
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

"""

import hal_glib                           # needed to make our own hal pins
import hal                                # needed to make our own hal pins
from gladevcp.persistence import IniFile  # we use this one to save the states of the widgets on shut down and restart
from gladevcp.persistence import widget_defaults
from gladevcp.persistence import select_widgets
import gtk
from gmoccapy import preferences
from gmoccapy import getiniinfo

class PlasmaClass:

    def __init__(self, halcomp, builder, useropts):
        self.builder = builder
        self.halcomp = halcomp
        self.defaults = { IniFile.vars : { 
#                                           "feedoverrideval"    : 1.0 ,
#                                           "feedoverridemax"    : 1.5 ,
#                                           "feedoverridemin"    : 0.01 ,
#                                           "feedoverrideincr"   : 0.01 ,
#
                                           "enableheightlock"  : False,

                                           "chlthresholdval"   : 60.0 ,
                                           "chlthresholdmax"   : 99.0,
                                           "chlthresholdmin"   : 5.0 ,
                                           "chlthresholdincr"  : 5.0 ,

                                           "enablekerfcross"  : False,

                                           "kerfcrossval"   : 60.0 ,
                                           "kerfcrossmax"   : 99.0,
                                           "kerfcrossmin"   : 5.0 ,
                                           "kerfcrossincr"  : 5.0 ,

                                           "enablethc"      : False,

                                         },
                        }

        get_ini_info = getiniinfo.GetIniInfo()
        prefs = preferences.preferences(get_ini_info.get_preference_file_path())
        theme_name = prefs.getpref("gtk_theme", "Follow System Theme", str)
        if theme_name == "Follow System Theme":
            theme_name = gtk.settings_get_default().get_property("gtk-theme-name")
        gtk.settings_get_default().set_string_property("gtk-theme-name", theme_name, "")

        self.ini_filename = __name__ + ".var"
        self.ini = IniFile(self.ini_filename, self.defaults, self.builder)
        self.ini.restore_state(self)

        # lets make our pins
#        self.feed_override = hal_glib.GPin(halcomp.newpin("Feed-Override-Main", hal.HAL_FLOAT, hal.HAL_OUT))
	self.THC_enable_in = hal_glib.GPin(halcomp.newpin("THC-Enable-In-Main", hal.HAL_BIT, hal.HAL_IN))

        #pins to link corner hold from plasma_tab tab through plasma.hal
	self.chld_threshold = hal_glib.GPin(halcomp.newpin("CHLD-Threshold-In-Main",hal.HAL_FLOAT, hal.HAL_IN))
        self.enbl_heightlock = hal_glib.GPin(halcomp.newpin("Enbl-Heightlock",hal.HAL_BIT, hal.HAL_IN))

        #pins to link kerf crossing from plasma_tab through plasma.hal
        self.kerf_crossing_threshold = hal_glib.GPin(halcomp.newpin("Kerf-Crossing-Threshold-In", hal.HAL_FLOAT, hal.HAL_IN))
        self.enbl_kerf_crossing = hal_glib.GPin(halcomp.newpin("Enbl-Kerf-Crossing-In", hal.HAL_BIT, hal.HAL_IN))

        # get all widgets and connect them
#        self.lbl_feed_override_main = self.builder.get_object("lbl_feed_override_main")


#        self.btn_feed_override_minus_main = self.builder.get_object("btn_feed_override_minus_main")
#        self.btn_feed_override_minus_main.connect("pressed", self.on_btn_feed_override_pressed, -1)

#        self.btn_feed_override_plus_main = self.builder.get_object("btn_feed_override_plus_main")
#        self.btn_feed_override_plus_main.connect("pressed", self.on_btn_feed_override_pressed, 1)

#        self.adj_feed_override_main = self.builder.get_object("adj_feed_override_main")
#        self.adj_feed_override_main.connect("value_changed", self.on_adj_feed_override_main_value_changed)
#        self.adj_feed_override_main.upper = self.feedoverridemax
#        self.adj_feed_override_main.lower = self.feedoverridemin
#        self.adj_feed_override_main.set_value(self.feedoverrideval)

        self.enable_HeightLock = self.builder.get_object("enable-HeightLock")
        self.enable_HeightLock.connect("toggled", self.on_enable_HeightLock_toggled)
        self.enable_HeightLock.set_active(self.enableheightlock)

        self.adj_CHL_threshold = self.builder.get_object("adj_CHL_threshold")
        self.adj_CHL_threshold.connect("value_changed", self.on_adj_CHL_threshold_value_changed)
#        self.adj_CHL_threshold.upper = self.chlthresholdmax
#        self.adj_CHL_threshold.lower = self.chlthresholdmin
        self.adj_CHL_threshold.set_value(self.chlthresholdval)

        self.enable_kerf_crossing = self.builder.get_object("enable-kerf-crossing")
        self.enable_kerf_crossing.connect("toggled", self.on_enable_kerf_crossing_toggled)
        self.enable_kerf_crossing.set_active(self.enablekerfcross)

        self.adj_kerf_threshold = self.builder.get_object("adj_kerf_threshold")
        self.adj_kerf_threshold.connect("value_changed", self.on_adj_kerf_threshold_value_changed)
#        self.adj_kerf_threshold.upper = self.kerfcrossmax
#        self.adj_kerf_threshold.lower = self.kerfcrossmin
        self.adj_kerf_threshold.set_value(self.kerfcrossval)

        self.enable_THC_main = self.builder.get_object("hal-btn-THC-main")
        self.enable_THC_main.connect("toggled",self.on_enable_THC_toggled)
        self.enable_THC_main.set_active(self.enablethc)

        #service value change on hal input pin
	self.enbl_heightlock.connect("value-changed", self._on_enable_HeightLock_toggled)

	#service value change on hal input pin
        self.chld_threshold.connect("value-changed", self._on_adj_CHL_threshold_value_changed)

        #service kerf crossing enable on hal input pin
        self.enbl_kerf_crossing.connect("value-changed", self._on_enable_kerf_crossing_toggled)

        #service kerf crossing adjustment from change on hal input pin
        self.kerf_crossing_threshold.connect("value-changed", self._on_adj_kerf_threshold_value_changed)

        #service THC enable from change on hal input pin
	self.THC_enable_in.connect("value-changed", self._on_enable_THC_toggled)


        self.tbl_voltage = self.builder.get_object("tbl_voltage")
        self.tbl_voltage.connect("destroy", self._on_destroy)

    def _on_destroy(self, obj, data = None):
        self.ini.save_state(self)

    # What to do on button pres events?

#    def on_btn_feed_override_pressed(self, widget, dir):
#        increment = self.feedoverrideincr * dir
#        self.feedoverrideval = self.adj_feed_override_main.get_value() + increment
#        self.adj_feed_override_main.set_value(self.feedoverrideval)


#    def on_adj_feed_override_main_value_changed(self, widget, data = None):
#        if widget.get_value() >= widget.upper:
#            self.btn_feed_override_plus_main.set_sensitive(False)
#        elif widget.get_value() <= widget.lower:
#            self.btn_feed_override_minus_main.set_sensitive(False)
#        else:
#            self.btn_feed_override_plus_main.set_sensitive(True)
#            self.btn_feed_override_minus_main.set_sensitive(True)
#        self.halcomp["Feed-Override-Main"] = widget.get_value()
       # self.lbl_feed_override_main.set_label("%d" % (widget.get_value()*100))

    def on_adj_CHL_threshold_value_changed(self, widget, data = None):
        self.chlthresholdval = widget.get_value()

    #this function is used if adjustment value is modified from hal
    def _on_adj_CHL_threshold_value_changed(self, hal_pin, data = None):
        if (hal_pin.get() * 100) != self.adj_CHL_threshold.get_value():
             self.adj_CHL_threshold.set_value(hal_pin.get() * 100)


    def on_adj_kerf_threshold_value_changed(self, widget, data = None):
        self.kerfcrossval = widget.get_value()

    #this function is used if adjustment value is modified from hal
    def _on_adj_kerf_threshold_value_changed(self, hal_pin, data = None):
        if hal_pin.get() !=  self.adj_kerf_threshold.get_value():
             self.adj_kerf_threshold.set_value(hal_pin.get())


    def on_enable_HeightLock_toggled(self, widget, data = None):
        self.enableheightlock = widget.get_active()

   #this function is used if enable is toggle from hal
    def _on_enable_HeightLock_toggled(self, hal_pin, data = None):
        if hal_pin.get() != self.enable_HeightLock.get_active():
             self.enable_HeightLock.set_active(hal_pin.get())

    def on_enable_kerf_crossing_toggled(self, widget, data = None):
        self.enablekerfcross = widget.get_active()

   #this function is used if enable is toggled from hal
    def _on_enable_kerf_crossing_toggled(self, hal_pin, data = None):
	if hal_pin.get() != self.enable_kerf_crossing.get_active():
             self.enable_kerf_crossing.set_active(hal_pin.get())

    def on_enable_THC_toggled(self, widget, data = None):
         self.enablethc = widget.get_active()

   #this function is used if THC enable is toggled from hal
    def _on_enable_THC_toggled(self, hal_pin, data = None):
	if hal_pin.get() != self.enable_THC_main.get_active():
             self.enable_THC_main.set_active(hal_pin.get())

def get_handlers(halcomp, builder, useropts):
    return[PlasmaClass(halcomp, builder, useropts)]
